%
% persistence_normalized.m
%
% parses the persitence data and displays results in normalized terms.
% variable filename must be set to a string containing the file name
% of the text input file.  Results are a JPG image, MPG and MOV files
% of the same name as filename.

clear date;

num_sites = 50;
num_samples = 161;

fid = fopen(filename);
temp = fscanf(fid,'%s',1);
sites = fscanf(fid,'%s',num_sites);

n_correction=0;
values = zeros(num_samples,num_sites);
for (n=1:num_samples)
   temp = fscanf(fid,'%s',1);
   % throw out data from incomplete jobs
   if ((strcmp(temp,'2001-04-01')) | (strcmp(temp,'2001-06-24')) | (strcmp(temp,'2001-07-29')) | (strcmp(temp,'2001-09-18')))
      n_correction=n_correction+1;
   	temp = fscanf(fid,'%d',num_sites);
   else   
	   date((n-n_correction),:) = temp;
   	temp = fscanf(fid,'%d',num_sites);
	   values(n-n_correction,1:num_sites) = temp';
   end;
end

[X,Y] = meshgrid(1:1:num_sites, 1:1:num_samples);

fig_number_n=figure;

for (n=1:num_sites)
	max_bytes(n) = max(values(:,n));
   if (max_bytes(n) ~= 0)
      values(:,n) = values(:,n)./max_bytes(n);
   else
      values(:,n) = zeros(num_samples,1);
	end
end

fig_number_n=figure;
surfl(X,Y,values)
colormap(summer);
shading interp;
token = strtok(filename,'.');
title (strcat(token,': normalized object size'));
xlabel('URL');
ylabel('date');
zlabel('bytes');
axis([1,num_sites,1,num_samples,0,1])
%axis square;
%axis vis3d;
view(3);

print -djpeg temp
copyfile ('temp.jpg', strcat(token,'_normalized.jpg'));
delete 'temp.jpg';

%create an MPG
fprintf ('creating MPG movie \n');
view(3);
map = colormap;
[az,el]=view;
M(1) = getframe(fig_number_n);
for a = 1:75
  az = az+1.0;
  view(az,el);
  M(a+1) = getframe(fig_number_n);%,RECT);
end
movie(M);
fprintf ('saving MPG movie \n');
mpgwrite(M,map,strcat(token,'_normalized.mpg'));%, [1 2 1 1 10 25])

% create a QT movie
fprintf ('creating QUICKTIME movie \n');
view(3);
MakeQTMovie('start',strcat(token,'_normalized.mov'));
MakeQTMovie('framerate',3);			% 3 frames per second
MakeQTMovie('quality',1);				% highest quality
[az,el]=view;
MakeQTMovie('addplot');
for (a=1:75)
   % change azimuth
   az = az+1.0;;
   view(az,el);
   MakeQTMovie('addplot');
end
fprintf ('saving QUICKTIME movie \n');
MakeQTMovie('finish');		

close(fig_number_n);
